# Glue Interactive Sessions Jupyter kernel

Glue Interactive Sessions Jupyter kernel enables you to use [AWS Glue Interactive Sessions](https://docs.aws.amazon.com/glue/latest/dg/interactive-sessions-overview.html) from your favorite IDEs. This kernel integrates almost anywhere Jupyter does including your favorite IDEs.
Documentation on how to install and use the kernel can also be found [here](https://docs.aws.amazon.com/glue/latest/dg/interactive-sessions.html).

## Installation

1. Use the following to install the kernel on your machine:

   The command, `install-glue-kernels`, installs the jupyter kernelspec for both pyspark and spark kernels.


   ```pip3 install --upgrade jupyter boto3 aws-glue-sessions```

   ```install-glue-kernels```

2. Make sure your IAM role have permissions to run Glue
   https://docs.aws.amazon.com/glue/latest/dg/set-up-iam.html

## Getting Started
### Using the kernel via a local Jupyter Notebook

To start a local Jupyter Notebook, complete the following steps.

1. Run the following command to launch Jupyter Notebook.

   `jupyter notebook`

2. Choose New, and then choose one of the AWS Glue kernels to begin coding against AWS Glue.

### Using the kernel via other IDEs

You may also use this kernel via VSCode or other IDEs that support Jupyter kernels.
To set up the Glue Interactive Sessions kernel for Visual Studio Code follow [these instructions](https://docs.aws.amazon.com/glue/latest/dg/interactive-sessions-vscode.html).


## ChangeLog

### v1.0.0 (2023-09-05)

* Kernel defaults to Glue version [4.0](https://aws.amazon.com/about-aws/whats-new/2022/11/introducing-aws-glue-4-0/) if a default Glue version wasn’t specified.
* New magics %session_type ,  %%assume_role, %%tags
* %list_sessions  now also displays session status and creation time.
* Support for additional visualizations through %matplotlib magic
* Configurations can now be provided through magics, environment variables and AWS config files.
* Fix for VSCode startup issue

